@@ -58,6 +58,7 @@ KateProjectView::KateProjectView(KateProjectPluginView *pluginView, KateProject
      */
     m_filter->setPlaceholderText(i18n("Filter..."));
     m_filter->setClearButtonEnabled(true);
+    m_filter->setProperty("_breeze_borders_sides", QVariant::fromValue(Qt::TopEdge | Qt::TopEdge));
     connect(m_filter, &KLineEdit::textChanged, this, [this] {
         m_filterStartTimer.start();
     });
@@ -133,5 +134,3 @@ void KateProjectView::checkAndRefreshGit()
     }
     m_pluginView->updateGitBranchButton(m_project);
 }
-
-#include "moc_kateprojectview.cpp"
