@@ -41,7 +41,7 @@ SnippetStore::SnippetStore()
         }
     }
 
-    for (const QString &file : qAsConst(files)) {
+    for (const QString &file : std::as_const(files)) {
         SnippetRepository *repo = new SnippetRepository(file);
         appendRow(repo);
     }
