@@ -11,16 +11,23 @@
 #include "kateviewmanager.h"
 
 #include <kcoreaddons_version.h>
+#include <kiconthemes_version.h>
 
 #include <KAboutData>
 #include <KConfigGui>
 #include <KCrash>
+#include <KIconTheme>
 #include <KLazyLocalizedString>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KNetworkMounts>
 #include <KSharedConfig>
 
+#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
+#if HAVE_STYLE_MANAGER
+#include <KStyleManager>
+#endif
+
 // signal handler for SIGINT & SIGTERM
 #ifdef Q_OS_UNIX
 #include <KSignalHandler>
@@ -32,6 +39,9 @@
 #define HAVE_X11 __has_include(<KStartupInfo>)
 #if HAVE_X11
 #include <KStartupInfo>
+#include <KWindowInfo>
+#include <KWindowSystem>
+#include <KX11Extras>
 #endif
 
 #ifdef WITH_KUSERFEEDBACK
@@ -118,6 +128,14 @@ void KateApp::initPreApplicationCreation(bool detach)
     }
 #endif
 
+    /**
+     * trigger initialisation of proper icon theme
+     * see https://invent.kde.org/frameworks/kiconthemes/-/merge_requests/136
+     */
+#if KICONTHEMES_VERSION >= QT_VERSION_CHECK(6, 3, 0)
+    KIconTheme::initTheme();
+#endif
+
     /**
      * enable dark mode for title bar on Windows
      */
@@ -190,12 +208,20 @@ KateApp::KateApp(const QCommandLineParser &args, const ApplicationMode mode, con
     , m_sessionManager(this, sessionsDir)
     , m_lastActivationChange(QDateTime::currentMSecsSinceEpoch())
 {
+#if HAVE_STYLE_MANAGER
+    /**
+     * trigger initialisation of proper application style
+     * see https://invent.kde.org/frameworks/kconfigwidgets/-/merge_requests/239
+     */
+    KStyleManager::initStyle();
+#else
     /**
      * For Windows and macOS: use Breeze if available
      * Of all tested styles that works the best for us
      */
 #if defined(Q_OS_MACOS) || defined(Q_OS_WIN)
     QApplication::setStyle(QStringLiteral("breeze"));
+#endif
 #endif
 
     /**
@@ -825,4 +851,23 @@ bool KateApp::isInsideTerminal()
     return insideTerminal;
 }
 
+qint64 KateApp::lastActivationChange() const
+{
+#if HAVE_X11
+    // we invert the result if we are on the wrong virtual desktop
+    // this allows for easy filtering in the client process, bug 486066
+    if (KWindowSystem::isPlatformX11()) {
+        for (auto win : m_mainWindows) {
+            KWindowInfo info(win->winId(), NET::WMDesktop);
+            if (info.valid() && info.isOnCurrentDesktop()) {
+                return m_lastActivationChange;
+            }
+        }
+        return -m_lastActivationChange;
+    }
+#endif
+
+    return m_lastActivationChange;
+}
+
 #include "moc_kateapp.cpp"
