@@ -275,7 +275,7 @@ void KateConfigDialog::addBehaviorPage()
     connect(m_tabsElided, &QCheckBox::toggled, this, &KateConfigDialog::slotChanged);
     vbox->addWidget(m_tabsElided);
 
-    m_openNewTabInFrontOfCurrent = new QCheckBox(i18n("Open new tab to the right of current tab."), this);
+    m_openNewTabInFrontOfCurrent = new QCheckBox(i18n("Open new tabs to the right of the current tab"), this);
     m_openNewTabInFrontOfCurrent->setChecked(cgGeneral.readEntry("Open New Tab To The Right Of Current", false));
     m_openNewTabInFrontOfCurrent->setToolTip(i18n("If unchecked the new tab will open at the end."));
     connect(m_openNewTabInFrontOfCurrent, &QCheckBox::toggled, this, &KateConfigDialog::slotChanged);
@@ -336,6 +336,22 @@ void KateConfigDialog::addBehaviorPage()
     m_urlBarShowSymbols->setChecked(cgGeneral.readEntry("Show Symbol In Navigation Bar", true));
     connect(m_urlBarShowSymbols, &QCheckBox::toggled, this, &KateConfigDialog::slotChanged);
 
+    buttonGroup = new QGroupBox(i18n("Diagnostics"), generalFrame);
+    vbox = new QVBoxLayout(buttonGroup);
+    hlayout = new QHBoxLayout;
+    vbox->addLayout(hlayout);
+    layout->addWidget(buttonGroup);
+    label = new QLabel(i18n("Diagnostics limit:"), buttonGroup);
+    m_diagnosticsLimit = new QSpinBox(buttonGroup);
+    m_diagnosticsLimit->setRange(-1, 50000);
+    m_diagnosticsLimit->setSpecialValueText(i18n("Unlimited"));
+    m_diagnosticsLimit->setValue(cgGeneral.readEntry("Diagnostics Limit", 12000));
+    m_diagnosticsLimit->setToolTip(i18n("Max number of diagnostics allowed in the Diagnostics toolview."));
+    label->setBuddy(m_diagnosticsLimit);
+    hlayout->addWidget(label);
+    hlayout->addWidget(m_diagnosticsLimit);
+    connect(m_diagnosticsLimit, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &KateConfigDialog::slotChanged);
+
     layout->addStretch(1); // :-] works correct without autoadd
 }
 
@@ -604,6 +620,8 @@ void KateConfigDialog::slotApply()
 
         cg.writeEntry("Show Symbol In Navigation Bar", m_urlBarShowSymbols->isChecked());
 
+        cg.writeEntry("Diagnostics Limit", m_diagnosticsLimit->value());
+
         // patch document modified warn state
         const QList<KTextEditor::Document *> &docs = KateApp::self()->documentManager()->documentList();
         for (KTextEditor::Document *doc : docs) {
@@ -624,7 +642,7 @@ void KateConfigDialog::slotApply()
 #endif
     }
 
-    for (const PluginPageListItem &plugin : qAsConst(m_pluginPages)) {
+    for (const PluginPageListItem &plugin : std::as_const(m_pluginPages)) {
         if (plugin.pluginPage) {
             plugin.pluginPage->apply();
         }
@@ -654,7 +672,7 @@ void KateConfigDialog::slotChanged()
 
 void KateConfigDialog::showAppPluginPage(KTextEditor::Plugin *p, int id)
 {
-    for (const PluginPageListItem &plugin : qAsConst(m_pluginPages)) {
+    for (const PluginPageListItem &plugin : std::as_const(m_pluginPages)) {
         if ((plugin.plugin == p) && (id == plugin.idInPlugin)) {
             setCurrentPage(plugin.pageWidgetItem);
             break;
