@@ -25,6 +25,13 @@
 #include <QStackedLayout>
 #include <QUrl>
 
+// makes no sense on macOS
+#ifdef Q_OS_MACOS
+#define KATE_ALLOW_MENU_BAR_HIDE 0
+#else
+#define KATE_ALLOW_MENU_BAR_HIDE 1
+#endif
+
 class QMenu;
 
 namespace KIO
@@ -227,7 +234,12 @@ private Q_SLOTS:
     void onApplicationStateChanged(Qt::ApplicationState);
 
 private Q_SLOTS:
+#if KATE_ALLOW_MENU_BAR_HIDE
     void toggleShowMenuBar(bool showMessage = true);
+    void ensureHamburgerBarSize();
+    void updateHamburgerMenu();
+#endif
+
     void toggleShowStatusBar();
     void toggleShowTabBar();
 
@@ -239,9 +251,6 @@ Q_SIGNALS:
     void tabBarToggled();
     void unhandledShortcutOverride(QEvent *e);
 
-    void widgetAdded(QWidget *);
-    void widgetRemoved(QWidget *);
-
 public:
     void openUrl(const QString &name = QString());
 
@@ -510,6 +519,11 @@ public Q_SLOTS:
         return toolView(identifier);
     }
 
+    QWidget *activeViewToolView(int pos)
+    {
+        return KateMDI::MainWindow::activeViewToolView(static_cast<KMultiTabBar::KMultiTabBarPosition>(pos));
+    }
+
     /**
      * Move the toolview \p widget to position \p pos.
      * \param widget the toolview to move, where the widget was constructed
@@ -604,8 +618,6 @@ private Q_SLOTS:
     void slotDocumentCloseSelected(const QList<KTextEditor::Document *> &);
 
 private:
-    void ensureHamburgerBarSize();
-
     /**
      * Wrapper of main window for KTextEditor
      */
@@ -641,11 +653,15 @@ private:
 
     // options: show statusbar + show path
     KToggleAction *m_paShowPath = nullptr;
-    KToggleAction *m_paShowMenuBar = nullptr;
     KToggleAction *m_paShowStatusBar = nullptr;
     KToggleAction *m_paShowTabBar = nullptr;
     KToggleAction *m_paShowUrlNavBar = nullptr;
 
+    // makes no sense on macOS
+#if KATE_ALLOW_MENU_BAR_HIDE
+    KToggleAction *m_paShowMenuBar = nullptr;
+#endif
+
     QWidget *m_bottomViewBarContainer = nullptr;
     KateContainerStackedLayout *m_bottomContainerStack = nullptr;
 
