@@ -887,6 +887,18 @@ bool Sidebar::isCollapsed()
     return m_splitter->sizes().at(m_ownSplitIndex) == 0;
 }
 
+ToolView *Sidebar::firstVisibleToolView()
+{
+    for (int i = 0; i < tabBarCount(); ++i) {
+        auto tabbar = tabBar(i);
+        if (tabbar->isToolActive()) {
+            Q_ASSERT(tabbar->tabCount() > 0);
+            return m_idToWidget[tabbar->activeTab()];
+        }
+    }
+    return nullptr;
+}
+
 void Sidebar::handleCollapse(int pos, int index)
 {
     Q_UNUSED(pos);
@@ -1707,6 +1719,15 @@ void MainWindow::setSidebarsVisibleInternal(bool visible, bool hideFullySilent)
     }
 }
 
+ToolView *MainWindow::activeViewToolView(KMultiTabBar::KMultiTabBarPosition pos)
+{
+    const auto side = static_cast<size_t>(pos);
+    if (side >= 4) {
+        return nullptr;
+    }
+    return m_sidebars[side]->firstVisibleToolView();
+}
+
 bool MainWindow::sidebarsVisible() const
 {
     return m_sidebarsVisible;
@@ -1823,7 +1844,7 @@ void MainWindow::startRestore(KConfigBase *config, const QString &group)
     }
 
     // restore the sidebars
-    for (auto &sidebar : qAsConst(m_sidebars)) {
+    for (auto &sidebar : std::as_const(m_sidebars)) {
         sidebar->startRestoreSession(cg);
     }
 
@@ -1915,6 +1936,11 @@ QWidget *MainWindow::createContainer(QWidget *parent, int index, const QDomEleme
     QWidget *createdContainer = KParts::MainWindow::createContainer(parent, index, element, containerAction);
     if (element.tagName() == QLatin1String("ToolBar")) {
         KAcceleratorManager::setNoAccel(createdContainer);
+
+        // ensure actions visible in any toolbar are hidden from the hamburger menu
+        if (auto hamburgerMenu = static_cast<KHamburgerMenu *>(actionCollection()->action(QStringLiteral("hamburger_menu")))) {
+            hamburgerMenu->hideActionsOf(createdContainer);
+        }
     }
     return createdContainer;
 }
