@@ -113,12 +113,16 @@ public:
 
         m_proxyModel.setFilterKeyColumn(0);
         m_proxyModel.setFilterRole(Qt::DisplayRole);
+        m_proxyModel.setRecursiveFilteringEnabled(true);
         m_itemView.setModel(&m_proxyModel);
         connect(&m_filterText, &QLineEdit::textChanged, &m_proxyModel, &FuzzyFilterModel::setFilterString);
         connect(&m_filterText, &QLineEdit::textChanged, this, [this] {
             auto index = m_proxyModel.index(0, 0);
             if (index.isValid()) {
                 m_itemView.setCurrentIndex(index);
+                if constexpr (std::is_same_v<ItemView, QTreeView>) {
+                    m_itemView.expandAll();
+                }
             }
         });
     }
@@ -227,10 +231,13 @@ public:
         if (role == Qt::DisplayRole) {
             return fi.fileName();
         } else if (role == Qt::DecorationRole) {
+            if (!m_decorationsEnabled) {
+                return {};
+            }
             if (fi.isDir()) {
                 return QIcon(QIcon::fromTheme(QStringLiteral("folder")));
             } else if (fi.isFile()) {
-                return QIcon::fromTheme(QMimeDatabase().mimeTypeForFile(fi).iconName());
+                return QIcon::fromTheme(QMimeDatabase().mimeTypeForFile(fi, QMimeDatabase::MatchExtension).iconName());
             }
         } else if (role == FileInfo) {
             return QVariant::fromValue(fi);
@@ -250,14 +257,7 @@ public:
         m_currentDir = dir;
 
         beginResetModel();
-        const auto fileInfos = dir.entryInfoList(QDir::NoDotAndDotDot | QDir::Files | QDir::Dirs | QDir::Hidden);
-        for (const auto &fi : fileInfos) {
-            if (fi.isDir()) {
-                m_fileInfos.push_back(fi);
-            } else if (QMimeDatabase().mimeTypeForFile(fi).inherits(QStringLiteral("text/plain"))) {
-                m_fileInfos.push_back(fi);
-            }
-        }
+        m_fileInfos = dir.entryInfoList(QDir::NoDotAndDotDot | QDir::Files | QDir::Dirs | QDir::Hidden);
         endResetModel();
     }
 
@@ -266,8 +266,14 @@ public:
         return m_currentDir;
     }
 
+    void enableDecorationRole()
+    {
+        m_decorationsEnabled = true;
+    }
+
 private:
-    std::vector<QFileInfo> m_fileInfos;
+    bool m_decorationsEnabled = false;
+    QList<QFileInfo> m_fileInfos;
     QDir m_currentDir;
 };
 
@@ -327,6 +333,9 @@ public:
         int w = m_list.view()->sizeHintForColumn(0) + (vScroll ? vScroll->height() / 2 : 0);
 
         setFixedSize(qMin(w, 500), qMin(h, 600));
+
+        // enable decorations after resizing is finished
+        m_model.enableDecorationRole();
     }
 
     void onClicked(const QModelIndex &idx, Qt::KeyboardModifiers mod)
@@ -415,11 +424,14 @@ public:
         m_activeView = v;
         m_tree.setModel(model);
         m_tree.view()->expandAll();
-        const auto idxToSelect = model->match(model->index(0, 0), 0, text, 1, Qt::MatchExactly);
-        if (!idxToSelect.isEmpty()) {
-            m_tree.setCurrentIndex(idxToSelect.constFirst());
-        }
+        const auto idxToSelect = m_tree.model()->match(model->index(0, 0), 0, text, 1, Qt::MatchExactly | Qt::MatchRecursive);
+
         updateGeometry();
+
+        if (!idxToSelect.isEmpty()) {
+            m_tree.view()->selectionModel()->setCurrentIndex(idxToSelect.constFirst(), QItemSelectionModel::ClearAndSelect);
+            m_tree.view()->scrollTo(idxToSelect.constFirst());
+        }
     }
 
     bool eventFilter(QObject *o, QEvent *e) override
@@ -474,12 +486,13 @@ public:
         for (int i = 0; i < rowCount; ++i) {
             const auto idx = model->index(i, 0, index);
             if (idx.data(SymbolRange).value<KTextEditor::Range>().overlapsLine(line)) {
-                return idx;
-            } else if (model->hasChildren(idx)) {
-                const auto childIdx = symbolForCurrentLine(model, idx, line);
-                if (childIdx.isValid()) {
-                    return childIdx;
+                if (model->hasChildren(idx)) {
+                    const auto childIdx = symbolForCurrentLine(model, idx, line);
+                    if (childIdx.isValid()) {
+                        return childIdx;
+                    }
                 }
+                return idx;
             }
         }
         return {};
@@ -600,6 +613,10 @@ public:
         onConfigChanged();
 
         connect(this, &QListView::clicked, this, &BreadCrumbView::onClicked);
+
+        m_cursorChangedTimer.setSingleShot(true);
+        m_cursorChangedTimer.setInterval(500ms);
+        m_cursorChangedTimer.callOnTimeout(this, &BreadCrumbView::updateSymbolsCrumb);
     }
 
     void updatePalette()
@@ -623,6 +640,9 @@ public:
         const auto &dirs = splittedUrl(baseDir, s);
 
         m_model.clear();
+        if (m_symbolsModel) {
+            m_symbolsModel->disconnect(this);
+        }
         m_symbolsModel = nullptr;
 
         size_t i = 0;
@@ -693,6 +713,7 @@ public:
 
     void addSymbolCrumb(QObject *lsp)
     {
+        m_lastCursorLine = -1;
         QAbstractItemModel *model = nullptr;
         QMetaObject::invokeMethod(lsp, "documentSymbolsModel", Q_RETURN_ARG(QAbstractItemModel *, model));
         m_symbolsModel = model;
@@ -702,14 +723,21 @@ public:
 
         connect(m_symbolsModel, &QAbstractItemModel::modelReset, this, &BreadCrumbView::updateSymbolsCrumb);
 
-        if (model->rowCount({}) == 0) {
-            return;
-        }
-
         const auto view = m_urlBar->viewManager()->activeView();
         disconnect(m_connToView);
         if (view) {
-            m_connToView = connect(view, &KTextEditor::View::cursorPositionChanged, this, &BreadCrumbView::updateSymbolsCrumb);
+            m_connToView = connect(view, &KTextEditor::View::cursorPositionChanged, this, [this](KTextEditor::View *, KTextEditor::Cursor pos) {
+                if (pos.line() != m_lastCursorLine) {
+                    // start if the line changed
+                    m_lastCursorLine = pos.line();
+                    m_cursorChangedTimer.start();
+                }
+            });
+        }
+
+        if (model->rowCount({}) == 0) {
+            // the symbols are not ready
+            return;
         }
 
         const auto idx = getSymbolCrumbText();
@@ -995,6 +1023,8 @@ private:
     QMetaObject::Connection m_connToView; // Only one conn at a time
     bool m_isNavigating = false;
     bool m_showSymbolCrumb = true;
+    int m_lastCursorLine = -1;
+    QTimer m_cursorChangedTimer;
 
 Q_SIGNALS:
     void unsetFocus();
